@@ -13,7 +13,7 @@
 #' used in the ensemble feature selection process.
 #' Each box represents the distribution of scores across different resampling
 #' iterations for a particular learner.
-#' * `"n_features`: Boxplot of the number of features selected by each learner
+#' * `"n_features"`: Boxplot of the number of features selected by each learner
 #' in the different resampling iterations.
 #' * `"stability"`: Barplot of stability score for each learner used in the
 #' ensemble feature selection. This plot shows how similar are the output feature
@@ -35,12 +35,11 @@
 #'
 #' @return [ggplot2::ggplot()].
 #' @examples
+#' if (mlr3misc::require_namespaces("mlr3fselect", quietly = TRUE)) {
 #' \donttest{
-#' if (requireNamespace("mlr3")) {
-#'   library(mlr3)
+#'   set.seed (42)
 #'   library(mlr3fselect)
 #'
-#'   set.seed (42)
 #'   efsr = ensemble_fselect(
 #'     fselector = fs("random_search"),
 #'     task = tsk("sonar"),
@@ -100,8 +99,7 @@ autoplot.EnsembleFSResult = function(
         color = .data[["learner_id"]])) +
         geom_point() +
         scale_color_viridis_d("Learner ID", end = 0.8, alpha = 0.8) +
-        xlab("Number of Features") +
-        ylab(measure_id) +
+        labs(x = "Number of Features", y = measure_id) +
         theme
 
       if (pareto_front == "stepwise") {
@@ -131,7 +129,7 @@ autoplot.EnsembleFSResult = function(
         fill = .data[["learner_id"]])) +
         geom_boxplot(show.legend = FALSE) +
         scale_fill_viridis_d(end = 0.8, alpha = 0.8) +
-        ylab(measure_id) +
+        labs(y = measure_id) +
         theme +
         theme(axis.title.x = element_blank())
     },
@@ -143,7 +141,7 @@ autoplot.EnsembleFSResult = function(
         fill = .data[["learner_id"]]))+
         geom_boxplot(show.legend = FALSE) +
         scale_fill_viridis_d(end = 0.8, alpha = 0.8) +
-        ylab("Number of Features") +
+        labs(y = "Number of Features") +
         theme +
         theme(axis.title.x = element_blank())
     },
@@ -163,7 +161,7 @@ autoplot.EnsembleFSResult = function(
         fill = .data[["learner_id"]])) +
         geom_bar(stat = "identity", alpha = 0.8, show.legend = FALSE) +
         scale_fill_viridis_d(end = 0.8, alpha = 0.8) +
-        ylab(stability_measure) +
+        labs(y = stability_measure) +
         theme +
         theme(axis.title.x = element_blank())
     },
