@@ -12,8 +12,8 @@
 #' * `"histogram"`: Histogram of residuals: \eqn{r = y - \hat{y}}{r = y - y.hat}.
 #' * `"residual"`: Plot of the residuals, with the response \eqn{\hat{y}}{y.hat} on the "x" and the residuals on the "y" axis.
 #'    By default a linear model is fitted via `geom_smooth(method = "lm")` to visualize the trend between x and y (by default colored blue).
-#' * `"confidence`: Scatterplot of "true" response vs. "predicted" response with
-#'    confidence intervals. Error bars calculated as object$reponse +- quantile * object$se and so only
+#' * `"confidence"`: Scatterplot of "true" response vs. "predicted" response with
+#'    confidence intervals. Error bars calculated as object$response +- quantile * object$se and so only
 #'    possible with `predict_type = "se"`. `geom_abline()` with `slope = 1` is added to the plot.
 #'
 #' @param object ([mlr3::PredictionRegr]).
@@ -29,25 +29,21 @@
 #'
 #' @export
 #' @examples
-#' if (requireNamespace("mlr3")) {
-#'   library(mlr3)
-#'   library(mlr3viz)
+#' if (mlr3misc::require_namespaces("mlr3learners", quietly = TRUE)) {
+#' library(mlr3learners)
 #'
-#'   task = tsk("mtcars")
-#'   learner = lrn("regr.rpart")
-#'   object = learner$train(task)$predict(task)
+#' task = tsk("mtcars")
+#' learner = lrn("regr.rpart")
+#' object = learner$train(task)$predict(task)
 #'
-#'   head(fortify(object))
-#'   autoplot(object)
-#'   autoplot(object, type = "histogram", binwidth = 1)
-#'   autoplot(object, type = "residual")
+#' head(fortify(object))
+#' autoplot(object)
+#' autoplot(object, type = "histogram", binwidth = 1)
+#' autoplot(object, type = "residual")
 #'
-#'  if (requireNamespace("mlr3learners")) {
-#'   library(mlr3learners)
-#'   learner = lrn("regr.ranger", predict_type = "se")
-#'   object = learner$train(task)$predict(task)
-#'   autoplot(object, type = "confidence")
-#'  }
+#' learner = lrn("regr.ranger", predict_type = "se")
+#' object = learner$train(task)$predict(task)
+#' autoplot(object, type = "confidence")
 #' }
 autoplot.PredictionRegr = function(object, type = "xy", binwidth = NULL, theme = theme_minimal(), quantile = 1.96, ...) {
   assert_choice(type, choices = c("xy", "histogram", "residual", "confidence"), null.ok = FALSE)
@@ -83,8 +79,7 @@ autoplot.PredictionRegr = function(object, type = "xy", binwidth = NULL, theme =
           alpha = 0.8,
           color = "black",
           binwidth = binwidth) +
-        xlab("Residuals") +
-        ylab("Density") +
+        labs(x = "Residuals", y = "Density") +
         theme
     },
 
@@ -102,8 +97,7 @@ autoplot.PredictionRegr = function(object, type = "xy", binwidth = NULL, theme =
           method = "lm",
           fill = viridis::viridis(1, begin = 0.5),
           color = viridis::viridis(1, begin = 0.5)) +
-        xlab("Response") +
-        ylab("Residuals") +
+        labs(x = "Response", y = "Residuals") +
         theme
     },
 
@@ -131,8 +125,7 @@ autoplot.PredictionRegr = function(object, type = "xy", binwidth = NULL, theme =
         geom_point(
           color = viridis::viridis(1, begin = 0.5),
           alpha = 0.8) +
-        xlab(sprintf("Response \u00B1 %sse", quantile)) +
-        ylab("Truth") +
+        labs(x = sprintf("Response \u00B1 %sse", quantile), y = "Truth") +
         theme
     },
 
