@@ -40,37 +40,34 @@
 #' @export
 #' @examples
 #' \donttest{
-#' if (requireNamespace("mlr3")) {
-#'   library(mlr3)
-#'   library(mlr3viz)
+#' if (mlr3misc::require_namespaces("precrec", quietly = TRUE)) {
+#' task = tsk("sonar")
+#' learner = lrn("classif.rpart", predict_type = "prob")
+#' resampling = rsmp("cv", folds = 3)
+#' object = resample(task, learner, resampling)
 #'
-#'   task = tsk("sonar")
-#'   learner = lrn("classif.rpart", predict_type = "prob")
-#'   resampling = rsmp("cv", folds = 3)
-#'   object = resample(task, learner, resampling)
+#' head(fortify(object))
 #'
-#'   head(fortify(object))
+#' # Default: boxplot
+#' autoplot(object)
 #'
-#'   # Default: boxplot
-#'   autoplot(object)
+#' # Histogram
+#' autoplot(object, type = "histogram", bins = 30)
 #'
-#'   # Histogram
-#'   autoplot(object, type = "histogram", bins = 30)
+#' # ROC curve, averaged over resampling folds:
+#' autoplot(object, type = "roc")
 #'
-#'   # ROC curve, averaged over resampling folds:
-#'   autoplot(object, type = "roc")
+#' # ROC curve of joint prediction object:
+#' autoplot(object$prediction(), type = "roc")
 #'
-#'   # ROC curve of joint prediction object:
-#'   autoplot(object$prediction(), type = "roc")
+#' # Precision Recall Curve
+#' autoplot(object, type = "prc")
 #'
-#'   # Precision Recall Curve
-#'   autoplot(object, type = "prc")
-#'
-#'   # Prediction Plot
-#'   task = tsk("iris")$select(c("Sepal.Length", "Sepal.Width"))
-#'   resampling = rsmp("cv", folds = 3)
-#'   object = resample(task, learner, resampling, store_models = TRUE)
-#'   autoplot(object, type = "prediction")
+#' # Prediction Plot
+#' task = tsk("iris")$select(c("Sepal.Length", "Sepal.Width"))
+#' resampling = rsmp("cv", folds = 3)
+#' object = resample(task, learner, resampling, store_models = TRUE)
+#' autoplot(object, type = "prediction")
 #' }
 #' }
 autoplot.ResampleResult = function(object, type = "boxplot", measure = NULL, predict_sets = "test", binwidth = NULL, theme = theme_minimal(), ...) {
@@ -89,7 +86,7 @@ autoplot.ResampleResult = function(object, type = "boxplot", measure = NULL, pre
           alpha = 0.8,
           show.legend = FALSE) +
         scale_x_discrete() +
-        ylab(measure$id) +
+        labs(y = measure$id) +
         theme +
         theme(axis.text.x.bottom = element_blank())
     },
@@ -103,8 +100,7 @@ autoplot.ResampleResult = function(object, type = "boxplot", measure = NULL, pre
           alpha = 0.8,
           color = "black",
           binwidth = binwidth) +
-        xlab(measure$id) +
-        ylab("Count") +
+        labs(x = measure$id, y = "Count") +
         theme
     },
 
@@ -119,7 +115,8 @@ autoplot.ResampleResult = function(object, type = "boxplot", measure = NULL, pre
         scale_color_viridis_d("Learner", begin = 0.5) +
         scale_fill_viridis_d("Learner", begin = 0.5) +
         theme +
-        theme(plot.title = element_blank(), legend.position = "none")
+        theme(legend.position = "none") +
+        labs(title = NULL)
     },
 
     "prc" = {
@@ -133,7 +130,7 @@ autoplot.ResampleResult = function(object, type = "boxplot", measure = NULL, pre
         scale_color_viridis_d("Learner", begin = 0.5) +
         scale_fill_viridis_d("Learner", begin = 0.5) +
         theme +
-        theme(plot.title = element_blank())
+        labs(title = NULL)
     },
 
     "prediction" = plot_learner_prediction_resample_result(object, predict_sets, theme = theme, ...),
@@ -309,7 +306,7 @@ task_data = function(object, predict_sets) {
   return(remove_named(data, ".row_id"))
 }
 
-# Generates a evenly distributed sequence of the same type as the input vector.
+# Generates an evenly distributed sequence of the same type as the input vector.
 # x: vector of any type (column of a task)
 # n (int): desired resolution
 # expand_range (num): expand the outer limits (only for numerics)
