@@ -1,10 +1,12 @@
+skip_if_not_installed("mlr3")
+
 test_that("autoplot.PredictionClassif decision boundary probability", {
   set.seed(42)
   task = mlr3::tsk("pima")$select(c("age", "pedigree"))
   learner = mlr3::lrn("classif.rpart", predict_type = "prob")$train(task)
 
   p = autoplot(learner, type = "prediction", task = task)
-  expect_true(is.ggplot(p))
+  expect_true(is_ggplot(p))
   expect_doppelganger("learner_classif_prob", p)
 })
 
@@ -14,6 +16,6 @@ test_that("autoplot.PredictionClassif decision boundary response", {
   learner = mlr3::lrn("classif.rpart")$train(task)
 
   p = autoplot(learner, type = "prediction", task = task)
-  expect_true(is.ggplot(p))
+  expect_true(is_ggplot(p))
   expect_doppelganger("learner_classif_response", p)
 })
