@@ -8,7 +8,7 @@ set.seed(42)
 test_that("autoplot.LearnerClassifCVGlmnet", {
   requireNamespace("mlr3learners")
   learner = mlr3::lrn("classif.cv_glmnet")$train(mlr3::tsk("wine"))
-  p = autoplot(learner, type = "ggfortify")
-  expect_true(is.ggplot(p))
+  suppressWarnings({p = autoplot(learner, type = "ggfortify")})
+  expect_true(is_ggplot(p))
   expect_doppelganger("learner_classif.cv_glmnet", p)
 })
