@@ -9,11 +9,11 @@ test_that("autoplot.LearnerClustHierarchical", {
 
   learner = mlr3::lrn("clust.agnes")$train(mlr3::tsk("usarrests"))
   p = autoplot(learner)
-  expect_true(is.ggplot(p))
+  expect_true(is_ggplot(p))
   expect_doppelganger("learner_clust.agnes", p)
 
   learner = mlr3::lrn("clust.hclust")$train(mlr3::tsk("usarrests"))
   p = autoplot(learner, type = "scree")
-  expect_true(is.ggplot(p))
+  expect_true(is_ggplot(p))
   expect_doppelganger("learner_clust.hclust", p)
 })
