@@ -8,7 +8,7 @@ set.seed(42)
 test_that("autoplot.LearnerRegrGlmnet", {
   requireNamespace("mlr3learners")
   learner = mlr3::lrn("regr.cv_glmnet")$train(mlr3::tsk("mtcars"))
-  p = autoplot(learner, type = "ggfortify")
-  expect_true(is.ggplot(p))
+  suppressWarnings(p <- autoplot(learner, type = "ggfortify"))
+  expect_true(is_ggplot(p))
   expect_doppelganger("learner_regr.cv_glmnet", p)
 })
