@@ -12,14 +12,14 @@ test_that("autoplot.PredictionClust", {
   prediction = learner$train(task)$predict(task)
 
   expect_warning(p <- autoplot(prediction, task, type = "scatter"), "Factor variables are omitted")
-  expect_true(is.ggplot(p))
+  expect_true(is_ggplot(p))
   expect_doppelganger("predictionclust_scatter", p)
 
-  p = autoplot(prediction, task, type = "sil")
-  expect_true(is.ggplot(p))
+  suppressWarnings({p = autoplot(prediction, task, type = "sil")})
+  expect_true(is_ggplot(p))
   expect_doppelganger("predictionclust_sil", p)
 
   p = autoplot(prediction, task, type = "pca")
-  expect_true(is.ggplot(p))
+  expect_true(is_ggplot(p))
   expect_doppelganger("predictionclust_pca", p)
 })
